function [r,paircount] = plot_pair_correlation2D_mp(dist,m,Lx,Ly,h)
% plot_pair_correlation2D_mp.m plots a histogram for the distribution of
% pairwise distances in a population of individuals in 2D space. r is the
% radius to the centre of a shell of width h
%   
% INPUTS: dist - array storing distances between pairs of cells
%            m - number of individuals
%           Lx - domain width
%           Ly - domain height
%            h - bin width (discretised distance)
% OUTPUTS:    rbins - discretised distance (radius to centre of shell)
%         paircount - no. distances in each bin

hyp=sqrt((Lx/2)^2+(Ly/2)^2);
rmax=ceil(hyp);
r=h/2:h:rmax; % histogram bin centres, radius r to centre of shell
rbins=0:h:rmax+h/2; % bin edges for histogram: discretised domain of pair displacements r
rho = m/(Lx*Ly); % estimate of average density of individuals (no. individuals/area of domain)
Ashell = 2*pi*r*h; % area of shell of radius r (to centre of shell) and width h
N=(m-1)*rho*Ashell; % normalisation: (no. of cells)*(av. density of cells in a shell of radius r around a cell i)
paircount=histc(dist, rbins)'; % compute pair counts
paircount=paircount(1:end-1)./N; % normalise pair counts and ignore last bin

%% Plot pair-correlation function:
% plot(r,paircount)
% xlabel('r'); ylabel('C(r)'); 
% title('Pair-correlation function')


end

